==> dara_components-1.1.4-py3-none-any.whl: dara/components/plotting/palettes.py <==
"""
Copyright 2023 Impulse Innovations Limited


Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

CategoricalLight10 = [
    '#3796F6',
    '#E28FFF',
    '#BA3C8B',
    '#2DB3BF',
    '#5E62E2',
    '#FF8F80',
    '#0790AE',
    '#DCB016',
    '#DA6087',
    '#2CB85C',
]

CategoricalLight9 = CategoricalLight10[:9]
CategoricalLight8 = CategoricalLight10[:8]
CategoricalLight7 = CategoricalLight10[:7]
CategoricalLight6 = CategoricalLight10[:6]
CategoricalLight5 = CategoricalLight10[:5]
CategoricalLight4 = CategoricalLight10[:4]
CategoricalLight3 = CategoricalLight10[:3]

CategoricalDark10 = [
    '#2485E8',
    '#D96FFF',
    '#AB2178',
    '#1A9FAC',
    '#5E31DC',
    '#DB6D5E',
    '#00849F',
    '#C8981F',
    '#CA456F',
    '#109C41',
]

CategoricalDark9 = CategoricalDark10[:9]
CategoricalDark8 = CategoricalDark10[:8]
CategoricalDark7 = CategoricalDark10[:7]
CategoricalDark6 = CategoricalDark10[:6]
CategoricalDark5 = CategoricalDark10[:5]
CategoricalDark4 = CategoricalDark10[:4]
CategoricalDark3 = CategoricalDark10[:3]


SequentialLight10 = [
    '#001C38',
    '#0D3863',
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#4CA1F8',
    '#74B5FA',
    '#9BC9FC',
    '#C3DEFE',
    '#EAF1FF',
]

SequentialLight9 = [
    '#001C38',
    '#0D3863',
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#4CA1F8',
    '#74B5FA',
    '#9BC9FC',
    '#EAF1FF',
]

SequentialLight8 = [
    '#0D3863',
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#4CA1F8',
    '#74B5FA',
    '#9BC9FC',
    '#EAF1FF',
]

SequentialLight7 = [
    '#0D3863',
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#4CA1F8',
    '#74B5FA',
    '#EAF1FF',
]

SequentialLight6 = [
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#4CA1F8',
    '#74B5FA',
    '#EAF1FF',
]

SequentialLight5 = [
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#74B5FA',
    '#EAF1FF',
]

SequentialLight4 = [
    '#19538D',
    '#3289E2',
    '#74B5FA',
    '#EAF1FF',
]

SequentialLight3 = [
    '#19538D',
    '#3289E2',
    '#EAF1FF',
]

SequentialDark10 = [
    '#EAF1FF',
    '#C3DDFD',
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#3189E2',
    '#2570BB',
    '#195694',
    '#104377',
    '#08335E',
]

SequentialDark9 = [
    '#EAF1FF',
    '#C3DDFD',
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#3189E2',
    '#2570BB',
    '#195694',
    '#08335E',
]

SequentialDark8 = [
    '#C3DDFD',
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#3189E2',
    '#2570BB',
    '#195694',
    '#08335E',
]

SequentialDark7 = [
    '#C3DDFD',
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#3189E2',
    '#2570BB',
    '#08335E',
]

SequentialDark6 = [
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#3189E2',
    '#2570BB',
    '#08335E',
]

SequentialDark5 = [
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#2570BB',
    '#08335E',
]

SequentialDark4 = [
    '#9BC9FB',
    '#4BA0F7',
    '#2570BB',
    '#08335E',
]

SequentialDark3 = [
    '#9BC9FB',
    '#4BA0F7',
    '#08335E',
]

PolarisingLight11 = [
    '#3796F6',
    '#62ABF4',
    '#8BC0F2',
    '#B6D4EF',
    '#E0E9ED',
    '#F4F3EB',
    '#F2E3E1',
    '#ECC3CA',
    '#E6A2B4',
    '#E0819E',
    '#DA6087',
]

PolarisingLight10 = [
    '#3796F6',
    '#62ABF4',
    '#8BC0F2',
    '#B6D4EF',
    '#E0E9ED',
    '#F2E3E1',
    '#ECC3CA',
    '#E6A2B4',
    '#E0819E',
    '#DA6087',
]

PolarisingLight9 = [
    '#3796F6',
    '#62ABF4',
    '#8BC0F2',
    '#B6D4EF',
    '#F4F3EB',
    '#F2E3E1',
    '#ECC3CA',
    '#E6A2B4',
    '#DA6087',
]

PolarisingLight8 = [
    '#3796F6',
    '#62ABF4',
    '#8BC0F2',
    '#B6D4EF',
    '#ECC3CA',
    '#E6A2B4',
    '#E0819E',
    '#DA6087',
]

PolarisingLight7 = [
    '#3796F6',
    '#8BC0F2',
    '#B6D4EF',
    '#F4F3EB',
    '#ECC3CA',
    '#E6A2B4',
    '#DA6087',
]

PolarisingLight6 = [
    '#3796F6',
    '#8BC0F2',
    '#B6D4EF',
    '#ECC3CA',
    '#E6A2B4',
    '#DA6087',
]

PolarisingLight5 = [
    '#3796F6',
    '#8BC0F2',
    '#F4F3EB',
    '#E6A2B4',
    '#DA6087',
]

PolarisingLight4 = [
    '#3796F6',
    '#8BC0F2',
    '#E6A2B4',
    '#DA6087',
]

PolarisingLight3 = [
    '#3796F6',
    '#F4F3EB',
    '#DA6087',
]

PolarisingDark11 = [
    '#2485E8',
    '#357FC4',
    '#46789E',
    '#587179',
    '#696A54',
    '#716640',
    '#7B6346',
    '#8F5C50',
    '#A3545B',
    '#B64D65',
    '#CA456F',
]

PolarisingDark10 = [
    '#2485E8',
    '#357FC4',
    '#46789E',
    '#587179',
    '#696A54',
    '#7B6346',
    '#8F5C50',
    '#A3545B',
    '#B64D65',
    '#CA456F',
]

PolarisingDark9 = [
    '#2485E8',
    '#357FC4',
    '#46789E',
    '#587179',
    '#716640',
    '#7B6346',
    '#8F5C50',
    '#A3545B',
    '#CA456F',
]

PolarisingDark8 = [
    '#2485E8',
    '#357FC4',
    '#46789E',
    '#587179',
    '#8F5C50',
    '#A3545B',
    '#B64D65',
    '#CA456F',
]

PolarisingDark7 = [
    '#2485E8',
    '#46789E',
    '#587179',
    '#716640',
    '#8F5C50',
    '#A3545B',
    '#CA456F',
]

PolarisingDark6 = [
    '#2485E8',
    '#46789E',
    '#587179',
    '#8F5C50',
    '#A3545B',
    '#CA456F',
]

PolarisingDark5 = [
    '#2485E8',
    '#46789E',
    '#716640',
    '#A3545B',
    '#CA456F',
]

PolarisingDark4 = [
    '#2485E8',
    '#46789E',
    '#A3545B',
    '#CA456F',
]

PolarisingDark3 = [
    '#2485E8',
    '#716640',
    '#CA456F',
]

CategoricalLight = {
    3: CategoricalLight3,
    4: CategoricalLight4,
    5: CategoricalLight5,
    6: CategoricalLight6,
    7: CategoricalLight7,
    8: CategoricalLight8,
    9: CategoricalLight9,
    10: CategoricalLight10,
}

CategoricalDark = {
    3: CategoricalDark3,
    4: CategoricalDark4,
    5: CategoricalDark5,
    6: CategoricalDark6,
    7: CategoricalDark7,
    8: CategoricalDark8,
    9: CategoricalDark9,
    10: CategoricalDark10,
}

SequentialLight = {
    3: SequentialLight3,
    4: SequentialLight4,
    5: SequentialLight5,
    6: SequentialLight6,
    7: SequentialLight7,
    8: SequentialLight8,
    9: SequentialLight9,
    10: SequentialLight10,
}

SequentialDark = {
    3: SequentialDark3,
    4: SequentialDark4,
    5: SequentialDark5,
    6: SequentialDark6,
    7: SequentialDark7,
    8: SequentialDark8,
    9: SequentialDark9,
    10: SequentialDark10,
}

PolarisingLight = {
    3: PolarisingLight3,
    4: PolarisingLight4,
    5: PolarisingLight5,
    6: PolarisingLight6,
    7: PolarisingLight7,
    8: PolarisingLight8,
    9: PolarisingLight9,
    10: PolarisingLight10,
    11: PolarisingLight11,
}

PolarisingDark = {
    3: PolarisingDark3,
    4: PolarisingDark4,
    5: PolarisingDark5,
    6: PolarisingDark6,
    7: PolarisingDark7,
    8: PolarisingDark8,
    9: PolarisingDark9,
    10: PolarisingDark10,
    11: PolarisingDark11,
}

==> dara_components-1.16.2-py3-none-any.whl: dara/components/plotting/palettes.py <==
"""
Copyright 2023 Impulse Innovations Limited


Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

CategoricalLight10 = [
    '#3796F6',
    '#E28FFF',
    '#BA3C8B',
    '#2DB3BF',
    '#5E62E2',
    '#FF8F80',
    '#0790AE',
    '#DCB016',
    '#DA6087',
    '#2CB85C',
]

CategoricalLight9 = CategoricalLight10[:9]
CategoricalLight8 = CategoricalLight10[:8]
CategoricalLight7 = CategoricalLight10[:7]
CategoricalLight6 = CategoricalLight10[:6]
CategoricalLight5 = CategoricalLight10[:5]
CategoricalLight4 = CategoricalLight10[:4]
CategoricalLight3 = CategoricalLight10[:3]
CategoricalLight2 = CategoricalLight10[:2]
CategoricalLight1 = CategoricalLight10[:1]

CategoricalDark10 = [
    '#2485E8',
    '#D96FFF',
    '#AB2178',
    '#1A9FAC',
    '#5E31DC',
    '#DB6D5E',
    '#00849F',
    '#C8981F',
    '#CA456F',
    '#109C41',
]

CategoricalDark9 = CategoricalDark10[:9]
CategoricalDark8 = CategoricalDark10[:8]
CategoricalDark7 = CategoricalDark10[:7]
CategoricalDark6 = CategoricalDark10[:6]
CategoricalDark5 = CategoricalDark10[:5]
CategoricalDark4 = CategoricalDark10[:4]
CategoricalDark3 = CategoricalDark10[:3]
CategoricalDark2 = CategoricalDark10[:2]
CategoricalDark1 = CategoricalDark10[:1]

SequentialLight10 = [
    '#001C38',
    '#0D3863',
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#4CA1F8',
    '#74B5FA',
    '#9BC9FC',
    '#C3DEFE',
    '#EAF1FF',
]

SequentialLight9 = [
    '#001C38',
    '#0D3863',
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#4CA1F8',
    '#74B5FA',
    '#9BC9FC',
    '#EAF1FF',
]

SequentialLight8 = [
    '#0D3863',
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#4CA1F8',
    '#74B5FA',
    '#9BC9FC',
    '#EAF1FF',
]

SequentialLight7 = [
    '#0D3863',
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#4CA1F8',
    '#74B5FA',
    '#EAF1FF',
]

SequentialLight6 = [
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#4CA1F8',
    '#74B5FA',
    '#EAF1FF',
]

SequentialLight5 = [
    '#19538D',
    '#256EB8',
    '#3289E2',
    '#74B5FA',
    '#EAF1FF',
]

SequentialLight4 = [
    '#19538D',
    '#3289E2',
    '#74B5FA',
    '#EAF1FF',
]

SequentialLight3 = [
    '#19538D',
    '#3289E2',
    '#EAF1FF',
]

SequentialLight2 = [
    '#19538D',
    '#EAF1FF',
]

SequentialLight1 = [
    '#19538D',
]

SequentialDark10 = [
    '#EAF1FF',
    '#C3DDFD',
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#3189E2',
    '#2570BB',
    '#195694',
    '#104377',
    '#08335E',
]

SequentialDark9 = [
    '#EAF1FF',
    '#C3DDFD',
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#3189E2',
    '#2570BB',
    '#195694',
    '#08335E',
]

SequentialDark8 = [
    '#C3DDFD',
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#3189E2',
    '#2570BB',
    '#195694',
    '#08335E',
]

SequentialDark7 = [
    '#C3DDFD',
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#3189E2',
    '#2570BB',
    '#08335E',
]

SequentialDark6 = [
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#3189E2',
    '#2570BB',
    '#08335E',
]

SequentialDark5 = [
    '#9BC9FB',
    '#73B5F9',
    '#4BA0F7',
    '#2570BB',
    '#08335E',
]

SequentialDark4 = [
    '#9BC9FB',
    '#4BA0F7',
    '#2570BB',
    '#08335E',
]

SequentialDark3 = [
    '#9BC9FB',
    '#4BA0F7',
    '#08335E',
]

SequentialDark2 = [
    '#9BC9FB',
    '#08335E',
]

SequentialDark1 = [
    '#9BC9FB',
]

PolarisingLight11 = [
    '#3796F6',
    '#62ABF4',
    '#8BC0F2',
    '#B6D4EF',
    '#E0E9ED',
    '#F4F3EB',
    '#F2E3E1',
    '#ECC3CA',
    '#E6A2B4',
    '#E0819E',
    '#DA6087',
]

PolarisingLight10 = [
    '#3796F6',
    '#62ABF4',
    '#8BC0F2',
    '#B6D4EF',
    '#E0E9ED',
    '#F2E3E1',
    '#ECC3CA',
    '#E6A2B4',
    '#E0819E',
    '#DA6087',
]

PolarisingLight9 = [
    '#3796F6',
    '#62ABF4',
    '#8BC0F2',
    '#B6D4EF',
    '#F4F3EB',
    '#F2E3E1',
    '#ECC3CA',
    '#E6A2B4',
    '#DA6087',
]

PolarisingLight8 = [
    '#3796F6',
    '#62ABF4',
    '#8BC0F2',
    '#B6D4EF',
    '#ECC3CA',
    '#E6A2B4',
    '#E0819E',
    '#DA6087',
]

PolarisingLight7 = [
    '#3796F6',
    '#8BC0F2',
    '#B6D4EF',
    '#F4F3EB',
    '#ECC3CA',
    '#E6A2B4',
    '#DA6087',
]

PolarisingLight6 = [
    '#3796F6',
    '#8BC0F2',
    '#B6D4EF',
    '#ECC3CA',
    '#E6A2B4',
    '#DA6087',
]

PolarisingLight5 = [
    '#3796F6',
    '#8BC0F2',
    '#F4F3EB',
    '#E6A2B4',
    '#DA6087',
]

PolarisingLight4 = [
    '#3796F6',
    '#8BC0F2',
    '#E6A2B4',
    '#DA6087',
]

PolarisingLight3 = [
    '#3796F6',
    '#F4F3EB',
    '#DA6087',
]

PolarisingLight2 = [
    '#3796F6',
    '#DA6087',
]

PolarisingLight1 = [
    '#3796F6',
]

PolarisingDark11 = [
    '#2485E8',
    '#357FC4',
    '#46789E',
    '#587179',
    '#696A54',
    '#716640',
    '#7B6346',
    '#8F5C50',
    '#A3545B',
    '#B64D65',
    '#CA456F',
]

PolarisingDark10 = [
    '#2485E8',
    '#357FC4',
    '#46789E',
    '#587179',
    '#696A54',
    '#7B6346',
    '#8F5C50',
    '#A3545B',
    '#B64D65',
    '#CA456F',
]

PolarisingDark9 = [
    '#2485E8',
    '#357FC4',
    '#46789E',
    '#587179',
    '#716640',
    '#7B6346',
    '#8F5C50',
    '#A3545B',
    '#CA456F',
]

PolarisingDark8 = [
    '#2485E8',
    '#357FC4',
    '#46789E',
    '#587179',
    '#8F5C50',
    '#A3545B',
    '#B64D65',
    '#CA456F',
]

PolarisingDark7 = [
    '#2485E8',
    '#46789E',
    '#587179',
    '#716640',
    '#8F5C50',
    '#A3545B',
    '#CA456F',
]

PolarisingDark6 = [
    '#2485E8',
    '#46789E',
    '#587179',
    '#8F5C50',
    '#A3545B',
    '#CA456F',
]

PolarisingDark5 = [
    '#2485E8',
    '#46789E',
    '#716640',
    '#A3545B',
    '#CA456F',
]

PolarisingDark4 = [
    '#2485E8',
    '#46789E',
    '#A3545B',
    '#CA456F',
]

PolarisingDark3 = [
    '#2485E8',
    '#716640',
    '#CA456F',
]

PolarisingDark2 = [
    '#2485E8',
    '#CA456F',
]

PolarisingDark1 = [
    '#2485E8',
]

CategoricalLight = {
    1: CategoricalLight1,
    2: CategoricalLight2,
    3: CategoricalLight3,
    4: CategoricalLight4,
    5: CategoricalLight5,
    6: CategoricalLight6,
    7: CategoricalLight7,
    8: CategoricalLight8,
    9: CategoricalLight9,
    10: CategoricalLight10,
}

CategoricalDark = {
    1: CategoricalDark1,
    2: CategoricalDark2,
    3: CategoricalDark3,
    4: CategoricalDark4,
    5: CategoricalDark5,
    6: CategoricalDark6,
    7: CategoricalDark7,
    8: CategoricalDark8,
    9: CategoricalDark9,
    10: CategoricalDark10,
}

SequentialLight = {
    1: SequentialLight1,
    2: SequentialLight2,
    3: SequentialLight3,
    4: SequentialLight4,
    5: SequentialLight5,
    6: SequentialLight6,
    7: SequentialLight7,
    8: SequentialLight8,
    9: SequentialLight9,
    10: SequentialLight10,
}

SequentialDark = {
    1: SequentialDark1,
    2: SequentialDark2,
    3: SequentialDark3,
    4: SequentialDark4,
    5: SequentialDark5,
    6: SequentialDark6,
    7: SequentialDark7,
    8: SequentialDark8,
    9: SequentialDark9,
    10: SequentialDark10,
}

PolarisingLight = {
    1: PolarisingLight1,
    2: PolarisingLight2,
    3: PolarisingLight3,
    4: PolarisingLight4,
    5: PolarisingLight5,
    6: PolarisingLight6,
    7: PolarisingLight7,
    8: PolarisingLight8,
    9: PolarisingLight9,
    10: PolarisingLight10,
    11: PolarisingLight11,
}

PolarisingDark = {
    1: PolarisingDark1,
    2: PolarisingDark2,
    3: PolarisingDark3,
    4: PolarisingDark4,
    5: PolarisingDark5,
    6: PolarisingDark6,
    7: PolarisingDark7,
    8: PolarisingDark8,
    9: PolarisingDark9,
    10: PolarisingDark10,
    11: PolarisingDark11,
}
